@@ -1722,3 +1722,25 @@ class TestRemoteVersion:
         assert "tuxbake: 0.3.1" in output
         assert "tuxmake: 1.10.0" in output
         assert "tuxrun: 0.36.0" in output
+
+
+class TestKeysCli:
+    def test_keys_no_args(self, monkeypatch, tuxsuite_config, capsys):
+        """Test calling keys with no options"""
+        monkeypatch.setattr(sys, "argv", ["tuxsuite", "keys"])
+        with pytest.raises(SystemExit) as exc:
+            tuxsuite.cli.main()
+        assert exc.value.code == 2
+        assert exc.type == SystemExit
+        output, error = capsys.readouterr()
+        assert "usage:" in error
+
+    def test_keys_usage(self, monkeypatch, capsys):
+        """Test calling keys with --help"""
+        monkeypatch.setattr(sys, "argv", ["tuxsuite", "keys", "--help"])
+        with pytest.raises(SystemExit) as exc:
+            tuxsuite.cli.main()
+        assert exc.value.code == 0
+        assert exc.type == SystemExit
+        output, error = capsys.readouterr()
+        assert "usage: tuxsuite keys [-h] {add,get,delete,update}" in output
