@@ -29,3 +29,14 @@ def post(config, url, data):
     return requests.post(
         f"{config.tuxapi_url}{url}", headers=headers(config), json=data
     )
+
+
+def delete(config, url):
+    # print(f"DELETE {config.tuxapi_url}{url}")
+    return requests.delete(f"{config.tuxapi_url}{url}", headers=headers(config))
+
+
+def put(config, url, data):
+    # print(f"PUT {config.tuxapi_url}{url}")
+    # print(f"PUT {data}")
+    return requests.put(f"{config.tuxapi_url}{url}", headers=headers(config), json=data)
